import os
import logging
import cv2
from numpy import ndarray

IMAGE_FORMAT = (".jpg", ".jpeg", ".png", ".bmp", ".tiff", ".pgm")

def check_image(image):
    """
    check_image method uses to status of check reading image .
    
    Args
    ----
    image: Image is able to string、numpy.ndarray instance.
    
    Return
    ------
    status: 
        0: image is numpy.ndarray instance.
        1: image is numpy.ndarray instance, but size is 0.
        2: image data type is None type.
    image: Numpy.ndarray instance.
    """
    
    status = None
    
    if type(image) == type(None):
        logging.warning("Image type is None !")
        status = 2
        
    elif type(image) == ndarray and image.size == 0:
        logging.warning("Image size is 0 !")
        status = 1
        
    elif type(image) == ndarray and image.size > 0:
        logging.debug("Image status is currect !")
        status = 0
        
    elif type(image) == str:
        # Check image fromat.
        if os.path.splitext(image)[-1].lower() not in IMAGE_FORMAT:
            logging.error("Image format error ! {} isn't image.".format(image))
            raise ValueError
        
        # Check image path.
        if os.path.exists(image): 
            image = cv2.imread(image)
            if type(image) == ndarray and image.size > 0:
                status = 0
            elif type(image) == ndarray and image.size == 0:
                status = 1
            else:
                status = 2
        else:
            logging.error("{} doesn't exist !".format(image))
            raise FileNotFoundError
    else:
        logging.warning("Check your image !")
        logging.debug("tools.exception.check_image.image type: {}".format(type(image)))
        raise TypeError
        
    return status, image


import time

VIDEO_FORMAT = (".mp4", ".m4v", ".mov", ".avi", ".wmv", ".flv", ".qt", ".asf", ".mpeg", ".mpg", ".vob", ".mkv",
                ".rm", ".rmvb", ".ts", ".dat")

class FPS(object):
    def __init__(self):
        self.frame = 0
        
    def start(self):
        self.start_time = time.time()
        
    def stop(self):
        self.elapsed_time = time.time() - self.start_time
    
    def update(self):
        self.frame += 1
        
    def fps(self):
        self.fps_value = self.frame / self.elapsed_time
        return self.fps_value


import setuptools

with open("README.md", "r", encoding="utf8") as readme:
    long_description = readme.read()

setuptools.setup(
    name="new_tools",
    version="0.0.6",
    author="Overcomer",
    author_email="michael31703@gmail.com",
    description="Multiple tools",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Michael07220823/new_tools.git",
    keywords="tools",
    install_requires=["opencv-python", "numpy"],
    license="MIT License",
    packages=setuptools.find_packages(include=["new_tools", "new_tools.*"]),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],

)